@@ -234,7 +234,7 @@ create_canvas (gboolean aa)
 	GtkWidget        *canvas = NULL;
 	GtkWidget        *frame;
 
-	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
+	gtk_widget_push_colormap (gdk_rgb_get_colormap ());
 
 	if (aa)
 		canvas = gnome_canvas_new_aa ();
@@ -280,7 +280,7 @@ create_canvas (gboolean aa)
 }
 
 GtkWidget *
-create_canvas_bezier_curve ()
+create_canvas_bezier_curve (void)
 {
 	GtkWidget *vbox;
 	GtkWidget *label;
